@@ -1,6 +1,6 @@
 /*
 JuffEd - An advanced text editor
-Copyright 2007-2009 Mikhail Murzin
+Copyright 2007-2010 Mikhail Murzin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License 
@@ -16,11 +16,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#ifndef __JUFF_APP_INFO_H__
-#define __JUFF_APP_INFO_H__
+#ifndef __JUFFED_APP_INFO_H__
+#define __JUFFED_APP_INFO_H__
 
 #ifdef Q_OS_WIN
 #include "AppInfo.win.h"
+#elif defined APPLEBUNDLE
+#include "AppInfo.apple.h"
 #else
 #include "AppInfo.nix.h"
 #endif
