@@ -16,24 +16,31 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#ifndef __JUFF_AUTOCOMPLETE_SETTINGS_H__
-#define __JUFF_AUTOCOMPLETE_SETTINGS_H__
+#ifndef __JUFFED_AUTOCOMPLETE_SETTINGS_H__
+#define __JUFFED_AUTOCOMPLETE_SETTINGS_H__
+
+#include "LibConfig.h"
 
 #include "Settings.h"
 
-class AutocompleteSettings : public Settings {
+class LIBJUFF_EXPORT AutocompleteSettings {
 public:
-	static bool useDocument();
-	static bool useApis();
-	static bool replaceWord();
-	static bool caseSensitive();
-	static int threshold();
+	enum IntKey {
+		Threshold,
+	};
+	
+	enum BoolKey {
+		ReplaceWord,
+		CaseSensitive,
+		UseDocument,
+		UseApis,
+	};
+	
+	static void set(IntKey, int);
+	static void set(BoolKey, bool);
 
-	static void setUseDocument(bool);
-	static void setUseApis(bool);
-	static void setReplaceWord(bool);
-	static void setCaseSensitive(bool);
-	static void setThreshold(int);
+	static int     get(IntKey);
+	static bool    get(BoolKey);
 };
 
-#endif // __JUFF_AUTOCOMPLETE_SETTINGS_H__
+#endif // __JUFFED_AUTOCOMPLETE_SETTINGS_H__
