@@ -1,6 +1,6 @@
 /*
 JuffEd - An advanced text editor
-Copyright 2007-2009 Mikhail Murzin
+Copyright 2007-2010 Mikhail Murzin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License 
@@ -19,9 +19,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __JUFF_FILE_TYPE_SETTINGS_H__
 #define __JUFF_FILE_TYPE_SETTINGS_H__
 
+#include "LibConfig.h"
+
 #include "Settings.h"
 
-class FileTypeSettings : public Settings {
+class LIBJUFF_EXPORT FileTypeSettings {
 public:
 	static QStringList getTypeList();
 	static QStringList getFileNamePatterns(const QString&);
