@@ -1,6 +1,6 @@
 /*
 JuffEd - An advanced text editor
-Copyright 2007-2009 Mikhail Murzin
+Copyright 2007-2010 Mikhail Murzin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License 
@@ -17,23 +17,24 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "KeySettings.h"
+#include "Settings.h"
 
-QKeySequence KeySettings::keySequence(Juff::CommandID id) {
-	QString idStr = QString::number(id);
-	if ( idStr.isEmpty() )
+QKeySequence KeySettings::keySequence(const QString& id) {
+	if ( id.isEmpty() ) {
 		return QKeySequence();
-	QString s = Settings::stringValue("keys", idStr);
+	}
+	QString s = Settings::instance()->stringValue("keys", id);
 	return QKeySequence(s);
 }
 
-void KeySettings::setKeySequence(Juff::CommandID id, const QKeySequence& seq) {
-	QString idStr = QString::number(id);
-	if ( idStr.isEmpty() )
+void KeySettings::setKeySequence(const QString& id, const QKeySequence& seq) {
+	if ( id.isEmpty() ) {
 		return;
-	Settings::setValue("keys", idStr, seq.toString());
+	}
+	Settings::instance()->setValue("keys", id, seq.toString());
 }
 
-bool KeySettings::contains(Juff::CommandID id) {
-	return keyList("keys").contains(QString::number(id));
+bool KeySettings::contains(const QString& id) {
+	return Settings::instance()->keyList("keys").contains(id);
 }
 
